@@ -32,10 +32,6 @@ class ClassificationTrainArguments:
                     "than this will be truncated, sequences shorter will be padded."
         }
     )
-    overwrite_model: bool = field(
-        default=False,
-        metadata={"help": "overwrite model checkpoints."}
-    )
     save_top_k: int = field(
         default=1,
         metadata={"help": "save top k model checkpoints."}
@@ -88,30 +84,10 @@ class ClassificationTrainArguments:
         default=False,
         metadata={"help": "Enable train on FP16"}
     )
-    do_train: bool = field(
-        default=True,
-        metadata={"help": "do train or not"}
-    )
-    do_eval: bool = field(
-        default=True,
-        metadata={"help": "do validation or not"}
-    )
-    do_predict: bool = field(
-        default=False,
-        metadata={"help": "do test or not"}
-    )
     tpu_cores: int = field(
         default=0,
         metadata={"help": "Enable TPU with 1 core or 8 cores"}
     )
-    report_cycle: int = field(
-        default=100,
-        metadata={"help": "Report (Train Metrics) Cycle"}
-    )
-    stat_window_length: int = field(
-        default=30,
-        metadata={"help": "train statistics window length"}
-    )
 
 
 @dataclass
